@@ -1,20 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -51,13 +50,14 @@
 #include <mailutils/mailbox.h>
 #include <mailutils/argp.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/nls.h>
 
 #ifdef ENABLE_VIRTUAL_DOMAINS
 
 static char *site_virtual_pwddir = SITE_VIRTUAL_PWDDIR;
 
 static struct passwd *
-getpwnam_virtual (char *u)
+getpwnam_virtual (const char *u)
 {
   struct passwd *pw = NULL;
   FILE *pfile;
@@ -133,7 +133,8 @@ getpwnam_ip_virtual (const char *u)
 
 /* Virtual domains */
 static int
-mu_auth_virt_domain_by_name (void *return_data, void *key,
+mu_auth_virt_domain_by_name (struct mu_auth_data **return_data,
+			     const void *key,
 			     void *unused_func_data, void *unused_call_data)
 {
   int rc;
@@ -157,7 +158,7 @@ mu_auth_virt_domain_by_name (void *return_data, void *key,
   mailbox_name = calloc (strlen (pw->pw_dir) + strlen ("/INBOX") + 1, 1);
   sprintf (mailbox_name, "%s/INBOX", pw->pw_dir);
 
-  rc = mu_auth_data_alloc ((struct mu_auth_data **) return_data,
+  rc = mu_auth_data_alloc (return_data,
 			   pw->pw_name,
 			   pw->pw_passwd,
 			   pw->pw_uid,
@@ -189,8 +190,8 @@ mu_virt_argp_parser (int key, char *arg, struct argp_state *state)
 }
 
 static struct argp_option mu_virt_argp_option[] = {
-  { "virtual-passwd-dir", ARG_PWDDIR, "DIR", 0,
-    "Search for virtual passwd file in DIR", 0},
+  { "virtual-passwd-dir", ARG_PWDDIR, N_("DIR"), 0,
+    N_("Search for virtual passwd file in DIR"), 0},
     { NULL,      0, NULL, 0, NULL, 0 }
 };
 
@@ -201,8 +202,10 @@ struct argp mu_virt_argp = {
 
 #else
 static int
-mu_auth_virt_domain_by_name (void *return_data, void *key,
-			     void *unused_func_data, void *unused_call_data)
+mu_auth_virt_domain_by_name (struct mu_auth_data **return_data ARG_UNUSED,
+			     const void *key ARG_UNUSED,
+			     void *func_data ARG_UNUSED,
+			     void *call_data ARG_UNUSED)
 {
   errno = ENOSYS;
   return 1;
