@@ -1,27 +1,28 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2004 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 /* This is an example program to illustrate the use of stream functions.
    It connects to a remote HTTP server and prints the contents of its
    index page */
-#include <stdlib.h>
+
 #include <stdio.h>
-#include <errno.h>
+#include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <unistd.h>
 
 #include <mailutils/mailutils.h>
@@ -30,17 +31,16 @@ const char *wbuf = "GET / HTTP/1.0\r\n\r\n";
 char rbuf[1024];
 
 int
-main ()
+main (void)
 {
-  int ret, off = 0, fd;
+  int ret, off = 0;
   stream_t stream;
   size_t nb;
-  fd_set fds;
-
+  
   ret = tcp_stream_create (&stream, "www.gnu.org", 80, MU_STREAM_NONBLOCK);
   if (ret != 0)
     {
-      mu_error ( "tcp_stream_create: %s\n", mu_errstring (ret));
+      mu_error ("tcp_stream_create: %s", mu_strerror (ret));
       exit (EXIT_FAILURE);
     }
 
@@ -50,25 +50,11 @@ connect_again:
     {
       if (ret == EAGAIN)
         {
-          ret = stream_get_fd (stream, &fd);
-          if (ret != 0)
-            {
-              mu_error ( "stream_get_fd: %s\n", mu_errstring (ret));
-              exit (EXIT_FAILURE);
-            }
-          FD_ZERO (&fds);
-          FD_SET (fd, &fds);
-          select (fd + 1, NULL, &fds, NULL, NULL);
+	  int wflags = MU_STREAM_READY_WR;
+	  stream_wait (stream, &wflags, NULL);
           goto connect_again;
         }
-      mu_error ( "stream_open: %s\n", mu_errstring (ret));
-      exit (EXIT_FAILURE);
-    }
-
-  ret = stream_get_fd (stream, &fd);
-  if (ret != 0)
-    {
-      mu_error ( "stream_get_fd: %s\n", mu_errstring (ret));
+      mu_error ("stream_open: %s", mu_strerror (ret));
       exit (EXIT_FAILURE);
     }
 
@@ -78,19 +64,18 @@ write_again:
     {
       if (ret == EAGAIN)
         {
-          FD_ZERO (&fds);
-          FD_SET (fd, &fds);
-          select (fd + 1, NULL, &fds, NULL, NULL);
+	  int wflags = MU_STREAM_READY_WR;
+	  stream_wait (stream, &wflags, NULL);
           off += nb;
           goto write_again;
         }
-      mu_error ( "stream_write: %s\n", mu_errstring (ret));
+      mu_error ("stream_write: %s", mu_strerror (ret));
       exit (EXIT_FAILURE);
     }
 
   if (nb != strlen (wbuf))
     {
-      mu_error ( "stream_write: %s\n", "nb != wbuf length");
+      mu_error ("stream_write: %s", "nb != wbuf length");
       exit (EXIT_FAILURE);
     }
 
@@ -101,24 +86,23 @@ write_again:
         {
           if (ret == EAGAIN)
             {
-              FD_ZERO (&fds);
-              FD_SET (fd, &fds);
-              select (fd + 1, &fds, NULL, NULL, NULL);
+	      int wflags = MU_STREAM_READY_RD;
+	      stream_wait (stream, &wflags, NULL);
             }
           else
             {
-              mu_error ( "stream_read: %s\n", mu_errstring (ret));
+              mu_error ("stream_read: %s", mu_strerror (ret));
               exit (EXIT_FAILURE);
             }
         }
-      write (2, rbuf, nb);
+      write (1, rbuf, nb);
     }
   while (nb || ret == EAGAIN);
 
   ret = stream_close (stream);
   if (ret != 0)
     {
-      mu_error ( "stream_close: %s\n", mu_errstring (ret));
+      mu_error ("stream_close: %s", mu_strerror (ret));
       exit (EXIT_FAILURE);
     }
 
