@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -125,6 +125,20 @@ extern int munre_set_regex __P((char *str, int caseflag, char **errp));
 extern int munre_subject  __P((const char *subject, const char **new_subject));
 
 extern char *mu_charset_lookup __P((char *lang, char *terr));
+
+extern int mu_true_answer_p __P((const char *p));
+extern int mu_scheme_autodetect_p __P((const char *scheme, const char **path));
+
+struct timeval; 
+  
+extern int mu_fd_wait __P((int fd, int *pflags, struct timeval *tvp));
+
+extern int mu_decode_filter __P((stream_t *pfilter, stream_t input,
+				 const char *filter_type,
+				 const char *fromcode, const char *tocode));
+
+extern enum mu_iconv_fallback_mode mu_default_fallback_mode;
+extern int mu_set_default_fallback __P((const char *str));
   
 #ifdef __cplusplus
 }
