@@ -51,7 +51,6 @@ mu_scm_mailbox_print (SCM mailbox_smob, SCM port, scm_print_state * pstate)
   struct mu_mailbox *mum = (struct mu_mailbox *) SCM_CDR (mailbox_smob);
   size_t count = 0;
   url_t url = NULL;
-  char *p;
 
   mailbox_messages_count (mum->mbox, &count);
   mailbox_get_url (mum->mbox, &url);
@@ -65,7 +64,7 @@ mu_scm_mailbox_print (SCM mailbox_smob, SCM port, scm_print_state * pstate)
     }
   else
     {
-      p = url_to_string (url);
+      const char *p = url_to_string (url);
       if (p)
 	{
 	  char buf[64];
@@ -160,7 +159,7 @@ SCM_DEFINE (mu_mailbox_close, "mu-mailbox-close", 1, 0, 0,
   mum = (struct mu_mailbox *) SCM_CDR (MBOX);
   mailbox_close (mum->mbox);
   mailbox_destroy (&mum->mbox);
-  return SCM_UNDEFINED;
+  return SCM_UNSPECIFIED;
 }
 #undef FUNC_NAME
 
