@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003,
+   2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -119,18 +120,26 @@ sieve_test_address (sieve_machine_t mach, list_t args, list_t tags)
   size_t count;
   
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "ADDRESS\n");
+    sieve_debug (mach, "%s:%lu: ADDRESS\n",
+		 mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
 
   h = sieve_value_get (args, 0);
   if (!h)
     {
-      sieve_error (mach, _("address: can't get argument 1"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'address' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("address: can't get argument 1"));
       sieve_abort (mach);
     }
   v = sieve_value_get (args, 1);
   if (!v)
     {
-      sieve_error (mach, _("address: can't get argument 2"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'address' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("address: can't get argument 2"));
       sieve_abort (mach);
     }
 
@@ -164,7 +173,7 @@ retrieve_header (void *item, void *data, int idx, char **pval)
       int i = hc->index++;
       if (strcasecmp (buf, (char*)item) == 0)
 	{
-	  if (header_aget_field_value (hc->header, i, pval))
+	  if (header_aget_field_value_unfold (hc->header, i, pval))
 	    return 1;
 	  return 0;
 	}
@@ -183,18 +192,26 @@ sieve_test_header (sieve_machine_t mach, list_t args, list_t tags)
   struct header_closure clos;
   
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "HEADER\n");
+    sieve_debug (mach, "%s:%lu: HEADER\n",
+		 mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
 
   h = sieve_value_get (args, 0);
   if (!h)
     {
-      sieve_error (mach, _("header: can't get argument 1"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'header' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("header: can't get argument 1"));
       sieve_abort (mach);
     }
   v = sieve_value_get (args, 1);
   if (!v)
     {
-      sieve_error (mach, _("header: can't get argument 2"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'header' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("header: can't get argument 2"));
       sieve_abort (mach);
     }
 
@@ -268,7 +285,9 @@ sieve_test_envelope (sieve_machine_t mach, list_t args, list_t tags)
   size_t count;
   
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "HEADER\n");
+    sieve_debug (mach, "%s:%lu: ENVELOPE\n",
+		 mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
 
   h = sieve_value_get (args, 0);
   if (!h)
@@ -279,7 +298,10 @@ sieve_test_envelope (sieve_machine_t mach, list_t args, list_t tags)
   v = sieve_value_get (args, 1);
   if (!v)
     {
-      sieve_error (mach, _("header: can't get argument 2"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'header' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("header: can't get argument 2"));
       sieve_abort (mach);
     }
 
@@ -302,7 +324,10 @@ sieve_test_size (sieve_machine_t mach, list_t args, list_t tags)
   sieve_value_t *val = sieve_value_get (args, 0);
   if (!val)
     {
-      sieve_error (mach, _("size: can't get argument!"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'size' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("size: can't get argument!"));
       sieve_abort (mach);
     }
 
@@ -322,7 +347,8 @@ int
 sieve_test_true (sieve_machine_t mach, list_t args, list_t tags)
 {
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "TRUE\n");
+    sieve_debug (mach, "%s:%lu: TRUE\n", mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
   return 1;
 }
 
@@ -330,7 +356,8 @@ int
 sieve_test_false (sieve_machine_t mach, list_t args, list_t tags)
 {
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "FALSE\n");
+    sieve_debug (mach, "%s:%lu: FALSE\n", mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
   return 0;
 }
 
@@ -350,13 +377,17 @@ sieve_test_exists (sieve_machine_t mach, list_t args, list_t tags)
   sieve_value_t *val;   
 
   if (mach->debug_level & MU_SIEVE_DEBUG_TRACE)
-    sieve_debug (mach, "EXISTS\n");
+    sieve_debug (mach, "%s:%lu: EXISTS\n", mach->locus.source_file,
+		 (unsigned long) mach->locus.source_line);
 
   message_get_header (sieve_get_message (mach), &header);
   val = sieve_value_get (args, 0);
   if (!val)
     {
-      sieve_error (mach, _("exists: can't get argument!"));
+      sieve_error (mach,
+		   /* TRANSLATORS: 'size' is the name of a Sieve test.
+		      Do not translate it! */
+		   _("exists: can't get argument!"));
       sieve_abort (mach);
     }
 
