@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003,
+   2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,6 +18,7 @@
 
 #include "mail.h"
 #include <mailutils/mutil.h>
+#include <mailutils/mime.h>
 #include <pwd.h>
 #ifdef HAVE_TERMIOS_H
 # include <termios.h>
@@ -58,7 +60,9 @@ util_ll_add (node *c, int data)
 
 /*
  * free a linked list
+ * Unused so far
  */
+#if 0
 static void
 util_ll_free (node *c)
 {
@@ -70,6 +74,7 @@ util_ll_free (node *c)
       free (c);
     }
 }
+#endif
 
 /*
  * expands command into its command and arguments, then runs command
@@ -116,7 +121,7 @@ util_do_command (const char *c, ...)
 	    return 0;
 	}
 
-      if (argcv_get (cmd, delim, NULL, &argc, &argv) == 0)
+      if (argcv_get (cmd, delim, NULL, &argc, &argv) == 0 && argc > 0)
 	{
 	  struct mail_command_entry entry;
 	  char *p;
@@ -147,9 +152,13 @@ util_do_command (const char *c, ...)
     }
   else
     {
-      util_error (_("Unknown command: %s"), argv[0]);
+      if (argc)
+	util_error (_("Unknown command: %s"), argv[0]);
+      else
+	util_error (_("Invalid command"));
       status = 1;
     }
+      
 
   argcv_free (argc, argv);
   return status;
@@ -535,6 +544,27 @@ util_setenv (const char *variable, void *value, mail_env_data_t type,
 	  
 	case Mail_env_string:
 	  ep->value.string = strdup (value);
+	  if (strcmp (variable, "replyregex") == 0)
+	    { 
+	      int rc;
+	      char *err;
+	      
+	      if (rc = munre_set_regex (value, 0, &err))
+		{
+		  fprintf (stderr, "%s", mu_strerror (rc));
+		  if (err)
+		    {
+		      fprintf (stderr, "%s", err);
+		      free (err);
+		    }
+		  fprintf (stderr, "\n");
+		}
+	    }
+	  else if (strcmp (variable, "decode-fallback") == 0)
+	    {
+	      if (mu_set_default_fallback (value))
+		mu_error (_("Incorrect value for decode-fallback"));
+	    }
 	  break;
 	  
 	case Mail_env_boolean:
@@ -548,6 +578,15 @@ util_setenv (const char *variable, void *value, mail_env_data_t type,
   return 0;
 }
 
+const char *
+util_reply_prefix ()
+{
+  char *prefix = "Re: ";
+  util_getenv (&prefix, "replyprefix", Mail_env_string, 0);
+  return prefix;
+}
+
+
 /* ************************* */
 
 /*
@@ -618,19 +657,18 @@ util_folder_path (const char *name)
 }
 
 char *
-util_get_sender(int msgno, int strip)
+util_get_sender (int msgno, int strip)
 {
-  header_t header = NULL;
-  address_t addr = NULL;
   message_t msg = NULL;
-  char buffer[512], *p;
+  address_t addr = NULL;
+  char *buf = NULL, *p;
 
   mailbox_get_message (mbox, msgno, &msg);
-  message_get_header (msg, &header);
-  if (header_get_value (header, MU_HEADER_FROM, buffer, sizeof(buffer), NULL)
-      || address_create (&addr, buffer))
+  addr = get_sender_address (msg);
+  if (!addr)
     {
       envelope_t env = NULL;
+      char buffer[512];
       message_get_envelope (msg, &env);
       if (envelope_sender (env, buffer, sizeof (buffer), NULL)
 	  || address_create (&addr, buffer))
@@ -640,7 +678,7 @@ util_get_sender(int msgno, int strip)
 	}
     }
 
-  if (address_get_email (addr, 1, buffer, sizeof(buffer), NULL))
+  if (address_aget_email (addr, 1, &buf))
     {
       util_error (_("can't determine sender name (msg %d)"), msgno);
       address_destroy (&addr);
@@ -649,23 +687,22 @@ util_get_sender(int msgno, int strip)
 
   if (strip)
     {
-      p = strchr (buffer, '@');
+      p = strchr (buf, '@');
       if (p)
 	*p = 0;
     }
 
-  p = strdup (buffer);
   address_destroy (&addr);
-  return p;
+  return buf;
 }
 
 void
-util_slist_print(list_t list, int nl)
+util_slist_print (list_t list, int nl)
 {
   iterator_t itr;
   char *name;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -678,13 +715,13 @@ util_slist_print(list_t list, int nl)
 }
 
 int
-util_slist_lookup(list_t list, char *str)
+util_slist_lookup (list_t list, char *str)
 {
   iterator_t itr;
   char *name;
   int rc = 0;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return 0;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -716,13 +753,31 @@ util_slist_add (list_t *list, char *value)
   list_append (*list, p);
 }
 
+static int
+comp (const void *item, const void *data)
+{
+  return strcmp ((char*)item, (char*)data);
+}
+
+void
+util_slist_remove (list_t *list, char *value)
+{
+  list_comparator_t cp;
+  
+  if (!*list)
+    return;
+  cp = list_set_comparator (*list, comp);
+  list_remove (*list, value);
+  list_set_comparator (*list, cp);
+}
+
 void
 util_slist_destroy (list_t *list)
 {
   iterator_t itr;
   char *name;
 
-  if (!*list || iterator_create (&itr, *list))
+  if (!*list || list_get_iterator (*list, &itr))
     return;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -741,7 +796,7 @@ util_slist_to_string (list_t list, const char *delim)
   char *name;
   char *str = NULL;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return NULL;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -1226,7 +1281,7 @@ util_get_message (mailbox_t mbox, size_t msgno, message_t *msg)
   if (msgno > total)
     {
       util_error_range (msgno);
-      return ENOENT;
+      return MU_ERR_NOENT;
     }
   
   status = mailbox_get_message (mbox, msgno, msg);
@@ -1252,3 +1307,82 @@ util_noapp ()
 {
   util_error (_("No applicable messages"));
 }
+
+void
+util_cache_command (list_t *list, const char *fmt, ...)
+{
+  char *cmd;
+  va_list ap;
+
+  va_start (ap, fmt);
+  vasprintf (&cmd, fmt, ap);
+  va_end (ap);
+
+  if (!*list)
+    list_create (list);
+
+  list_append (*list, cmd);
+}
+
+static int
+_run_and_free (void *item, void *data)
+{
+  util_do_command ((char *) item);
+  free (item);
+  return 0;
+}
+
+void
+util_run_cached_commands (list_t *list)
+{
+  list_do (*list, _run_and_free, NULL);
+  list_destroy (list);
+}
+
+void
+util_rfc2047_decode (char **value)
+{
+  char *charset = NULL;
+  char *tmp;
+  int rc;
+
+  if (!*value || util_getenv (&charset, "charset", Mail_env_string, 0))
+    return;
+  if (strcasecmp (charset, "auto") == 0)
+    {
+      /* Try to deduce the charset from LC_ALL or LANG variables */
+
+      tmp = getenv ("LC_ALL");
+      if (!tmp)
+	tmp = getenv ("LANG");
+
+      if (tmp)
+	{
+	  char *sp;
+	  char *lang;
+	  char *terr;
+
+	  lang = strtok_r (tmp, "_", &sp);
+	  terr = strtok_r (NULL, ".", &sp);
+	  charset = strtok_r (NULL, "@", &sp);
+
+	  if (!charset)
+	    charset = mu_charset_lookup (lang, terr);
+	}
+    }
+
+  if (!charset)
+    return;
+  
+  rc = rfc2047_decode (charset, *value, &tmp);
+  if (rc)
+    {
+      if (util_getenv (NULL, "verbose", Mail_env_boolean, 0) == 0)
+	mu_error (_("Can't decode line `%s': %s"), *value, mu_strerror (rc));
+    }
+  else
+    {
+      free (*value);
+      *value = tmp;
+    }
+}
