@@ -26,6 +26,7 @@
 
 #include <mailutils/list.h>
 #include <mailutils/monitor.h>
+#include <mailutils/iterator.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -44,6 +45,8 @@ struct _list
   size_t count;
   monitor_t monitor;
   list_comparator_t comp;
+  void (*destroy_item) __P((void *item));
+  struct _iterator *itr;
 };
 
 
