@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003,
+   2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -77,8 +78,8 @@ static int mbox_append_message0       __P ((mailbox_t, message_t, off_t *,
 static int mbox_message_uid           __P ((message_t, size_t *));
 static int mbox_header_fill           __P ((header_t, char *, size_t, off_t,
 					    size_t *));
-static int mbox_get_body_fd           __P ((stream_t, int *, int *));
-static int mbox_get_fd                __P ((mbox_message_t, int *));
+static int mbox_get_body_transport    __P ((stream_t, mu_transport_t *, mu_transport_t *));
+static int mbox_get_transport2         __P ((mbox_message_t, mu_transport_t *, mu_transport_t *));
 static int mbox_get_attr_flags        __P ((attribute_t, int *));
 static int mbox_set_attr_flags        __P ((attribute_t, int));
 static int mbox_unset_attr_flags      __P ((attribute_t, int));
@@ -171,7 +172,7 @@ _mailbox_mbox_init (mailbox_t mailbox)
     property_set_value (property, "TYPE", "MBOX", 1);
   }
 
-  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE, "mbox_init(%s)\n", mud->name);
+  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE, "mbox_init (%s)\n", mud->name);
   return 0; /* okdoke */
 }
 
@@ -264,7 +265,7 @@ mbox_open (mailbox_t mailbox, int flags)
 	return status;
     }
 
-  MAILBOX_DEBUG2 (mailbox, MU_DEBUG_TRACE, "mbox_open(%s, 0x%x)\n",
+  MAILBOX_DEBUG2 (mailbox, MU_DEBUG_TRACE, "mbox_open (%s, 0x%x)\n",
 		  mud->name, mailbox->flags);
 
   if (mailbox->locker == NULL)
@@ -281,7 +282,7 @@ mbox_close (mailbox_t mailbox)
   if (mud == NULL)
     return EINVAL;
 
-  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE,  "mbox_close(%s)\n", mud->name);
+  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE,  "mbox_close (%s)\n", mud->name);
 
   /* Make sure that we do not hold any file locking.  */
   locker_unlock (mailbox->locker);
@@ -327,7 +328,7 @@ mbox_scan (mailbox_t mailbox, size_t msgno, size_t *pcount)
 {
   size_t i;
   mbox_data_t mud = mailbox->data;
-  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE, "mbox_scan(%s)\n", mud->name);
+  MAILBOX_DEBUG1 (mailbox, MU_DEBUG_TRACE, "mbox_scan (%s)\n", mud->name);
   if (! mbox_is_updated (mailbox))
     return mbox_scan0 (mailbox, msgno, pcount, 1);
   /* Since the mailbox is already updated fake the scan. */
@@ -828,27 +829,20 @@ mbox_message_uid (message_t msg, size_t *puid)
 }
 
 static int
-mbox_get_body_fd (stream_t is, int *pfd, int *pfd2)
+mbox_get_body_transport (stream_t is, mu_transport_t *pin, mu_transport_t *pout)
 {
-  if (pfd2)
-    return ENOSYS;
-  else
-    {
-      body_t body = stream_get_owner (is);
-      message_t msg = body_get_owner (body);
-      mbox_message_t mum = message_get_owner (msg);
-      return mbox_get_fd (mum, pfd);
-    }
+  body_t body = stream_get_owner (is);
+  message_t msg = body_get_owner (body);
+  mbox_message_t mum = message_get_owner (msg);
+  return mbox_get_transport2 (mum, pin, pout);
 }
 
 static int
-mbox_get_fd (mbox_message_t mum, int *pfd)
+mbox_get_transport2 (mbox_message_t mum, mu_transport_t *pin, mu_transport_t *pout)
 {
-  int status;
   if (mum == NULL)
     return EINVAL;
-  status = stream_get_fd (mum->mud->mailbox->stream, pfd);
-  return status;
+  return stream_get_transport2 (mum->mud->mailbox->stream, pin, pout);
 }
 
 static int
@@ -984,7 +978,7 @@ mbox_header_get_fvalue (header_t header, const char *name, char *buffer,
   size_t i, fv_len = 0;
   message_t msg = header_get_owner (header);
   mbox_message_t mum = message_get_owner (msg);
-  int err = ENOENT;
+  int err = MU_ERR_NOENT;
   for (i = 0; i < HDRSIZE; i++)
     {
       if (*name == *(fhdr_table[i]) && strcasecmp (fhdr_table[i], name) == 0)
@@ -1003,7 +997,7 @@ mbox_header_get_fvalue (header_t header, const char *name, char *buffer,
 	      err = 0;
 	    }
 	  else
-	    err = ENOENT;
+	    err = MU_ERR_NOENT;
 	  break;
 	}
     }
@@ -1167,7 +1161,9 @@ mbox_get_message (mailbox_t mailbox, size_t msgno, message_t *pmsg)
   message_t msg = NULL;
 
   /* Sanity checks.  */
-  if (pmsg == NULL || mud == NULL)
+  if (pmsg == NULL)
+    return MU_ERR_OUT_PTR_NULL;
+  if (mud == NULL)
     return EINVAL;
 
   /* If we did not start a scanning yet do it now.  */
@@ -1194,7 +1190,7 @@ mbox_get_message (mailbox_t mailbox, size_t msgno, message_t *pmsg)
       return 0;
     }
 
-  MAILBOX_DEBUG2 (mailbox, MU_DEBUG_TRACE, "mbox_get_message(%s, %d)\n",
+  MAILBOX_DEBUG2 (mailbox, MU_DEBUG_TRACE, "mbox_get_message (%s, %d)\n",
 		  mud->name, msgno);
 
   /* Get an empty message struct.  */
@@ -1249,7 +1245,7 @@ mbox_get_message (mailbox_t mailbox, size_t msgno, message_t *pmsg)
       }
     stream_set_read (stream, mbox_body_read, body);
     stream_set_readline (stream, mbox_body_readline, body);
-    stream_set_fd (stream, mbox_get_body_fd, body);
+    stream_set_get_transport2 (stream, mbox_get_body_transport, body);
     stream_set_size (stream, mbox_stream_size, body);
     body_set_stream (body, stream, msg);
     body_set_size (body, mbox_body_size, msg);
@@ -1287,6 +1283,7 @@ mbox_append_message (mailbox_t mailbox, message_t msg)
 {
   int status = 0;
   mbox_data_t mud = mailbox->data;
+
   if (msg == NULL || mud == NULL)
     return EINVAL;
 
@@ -1333,7 +1330,8 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
   int status = 0;
   size_t n = 0;
   char nl = '\n';
-
+  size_t orig_size = *psize;
+  
   switch (mud->state)
     {
     case MBOX_NO_STATE:
@@ -1407,11 +1405,15 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 	/* Write the separator to the mailbox.  */
 	n = snprintf (buffer, sizeof (buffer), "From %s %s",
 		      mud->sender, mud->date);
-	stream_write (mailbox->stream, buffer, n, *psize, &n);
+	status = stream_write (mailbox->stream, buffer, n, *psize, &n);
+	if (status)
+	  break;
 	*psize += n;
 
 	/* Add the newline, the above may be truncated.  */
-	stream_write (mailbox->stream, &nl , 1, *psize, &n);
+	status = stream_write (mailbox->stream, &nl , 1, *psize, &n);
+	if (status)
+	  break;
 	*psize += n;
 
 	free (mud->sender);
@@ -1448,6 +1450,7 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 		    mud->state = MBOX_NO_STATE;
 		    mud->off = 0;
 		  }
+		stream_truncate (mailbox->stream, orig_size);
 		return status;
 	      }
 	    mud->off += nread;
@@ -1470,7 +1473,7 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 
 	    status = stream_write (mailbox->stream, buffer, nread,
 				    *psize, &n);
-	    if (status != 0)
+	    if (status)
 	      break;
 	    *psize += n;
 	  }
@@ -1483,7 +1486,9 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 	    n = sprintf (buffer, "X-IMAPbase: %lu %u\n",
 			 (unsigned long) mud->uidvalidity,
 			 (unsigned) mud->uidnext);
-	    stream_write (mailbox->stream, buffer, n, *psize, &n);
+	    status = stream_write (mailbox->stream, buffer, n, *psize, &n);
+	    if (status)
+	      break;
 	    *psize += n;
 	  }
 	mud->state = MBOX_STATE_APPEND_ATTRIBUTE;
@@ -1526,14 +1531,14 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 	    n = sprintf (suid, "X-UID: %u\n", (unsigned) uid);
 	    /* Put the UID.  */
 	    status = stream_write (mailbox->stream, suid, n, *psize, &n);
-	    if (status != 0)
+	    if (status)
 	      break;
 	    *psize += n;
 	  }
 
 	/* New line separator of the Header.  */
 	status = stream_write (mailbox->stream, &nl , 1, *psize, &n);
-	if (status != 0)
+	if (status)
 	  break;
 	*psize += n;
 	mud->state = MBOX_STATE_APPEND_BODY;
@@ -1563,14 +1568,16 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 	      }
 	    mud->off += nread;
 	    status = stream_write (mailbox->stream, buffer, nread, *psize, &n);
-	    if (status != 0)
+	    if (status)
 	      break;
 	    *psize += n;
 	  }
 	while (nread > 0);
 	mud->off = 0;
 	n = 0;
-	stream_write (mailbox->stream, &nl, 1, *psize, &n);
+	status = stream_write (mailbox->stream, &nl, 1, *psize, &n);
+	if (status)
+	  break;
 	*psize += n;
       }
 
@@ -1601,16 +1608,21 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 			mud->state = MBOX_NO_STATE;
 			mud->off = 0;
 		      }
-		    stream_flush (mailbox->stream);
+		    stream_truncate (mailbox->stream, orig_size);
 		    return status;
 		  }
-		stream_write (mailbox->stream, buffer, nread, *psize, &n);
+		status = stream_write (mailbox->stream, buffer, nread,
+				       *psize, &n);
+		if (status)
+		  break;
 		mud->off += nread;
 		*psize += n;
 	      }
 	    while (nread > 0);
 	    n = 0;
-       	    stream_write (mailbox->stream, &nl, 1, *psize, &n);
+       	    status = stream_write (mailbox->stream, &nl, 1, *psize, &n);
+	    if (status)
+	      break;
 	    *psize += n;
 	  }
 
@@ -1619,7 +1631,10 @@ mbox_append_message0 (mailbox_t mailbox, message_t msg, off_t *psize,
 	}
     } /* is_expunging */
   mud->state = MBOX_NO_STATE;
-  stream_flush (mailbox->stream);
+  if (status)
+    stream_truncate (mailbox->stream, orig_size);
+  else
+    stream_flush (mailbox->stream);
   return status;
 }
 
@@ -1642,6 +1657,7 @@ static int
 mbox_messages_count (mailbox_t mailbox, size_t *pcount)
 {
   mbox_data_t mud = mailbox->data;
+
   if (mud == NULL)
     return EINVAL;
 
