@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Library Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -48,6 +48,7 @@
 #include <mailutils/observer.h>
 #include <mailutils/stream.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/nls.h>
 
 #define MESSAGE_MODIFIED 0x10000;
 
@@ -55,7 +56,8 @@ static int message_read   __P ((stream_t is, char *buf, size_t buflen,
 				off_t off, size_t *pnread ));
 static int message_write  __P ((stream_t os, const char *buf, size_t buflen,
 				off_t off, size_t *pnwrite));
-static int message_get_fd __P ((stream_t stream, int *pfd));
+static int message_get_transport2 __P ((stream_t stream, mu_transport_t *pin, 
+                                       mu_transport_t *pout));
 static int message_sender __P ((envelope_t envelope, char *buf, size_t len,
 				size_t *pnwrite));
 static int message_date   __P ((envelope_t envelope, char *buf, size_t len,
@@ -75,7 +77,7 @@ message_create (message_t *pmsg, void *owner)
   int status;
 
   if (pmsg == NULL)
-    return EINVAL;
+    return MU_ERR_OUT_PTR_NULL;
   msg = calloc (1, sizeof (*msg));
   if (msg == NULL)
     return ENOMEM;
@@ -172,7 +174,9 @@ message_create_copy (message_t *to, message_t from)
   size_t n = 0;
   char buf[512];
 
-  if(!to || !from)
+  if (!to)
+    return MU_ERR_OUT_PTR_NULL;
+  if (!from)
     return EINVAL;
 
   if((status = message_create (to, NULL)))
@@ -248,8 +252,10 @@ message_clear_modified (message_t msg)
 int
 message_get_mailbox (message_t msg, mailbox_t *pmailbox)
 {
-  if (msg == NULL || pmailbox == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (pmailbox == NULL)
+    return MU_ERR_OUT_PTR_NULL;
   *pmailbox = msg->mailbox;
   return 0;
 }
@@ -268,8 +274,10 @@ message_set_mailbox (message_t msg, mailbox_t mailbox, void *owner)
 int
 message_get_header (message_t msg, header_t *phdr)
 {
-  if (msg == NULL || phdr == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (phdr == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   /* Is it a floating mesg */
   if (msg->header == NULL)
@@ -310,8 +318,10 @@ message_set_header (message_t msg, header_t hdr, void *owner)
 int
 message_get_body (message_t msg, body_t *pbody)
 {
-  if (msg == NULL || pbody == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (pbody == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   /* Is it a floating mesg.  */
   if (msg->body == NULL)
@@ -381,8 +391,10 @@ message_set_stream (message_t msg, stream_t stream, void *owner)
 int
 message_get_stream (message_t msg, stream_t *pstream)
 {
-  if (msg == NULL || pstream == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (pstream == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   if (msg->stream == NULL)
     {
@@ -393,7 +405,7 @@ message_get_stream (message_t msg, stream_t *pstream)
 	return status;
       stream_set_read (stream, message_read, msg);
       stream_set_write (stream, message_write, msg);
-      stream_set_fd (stream, message_get_fd, msg);
+      stream_set_get_transport2 (stream, message_get_transport2, msg);
       stream_set_size (stream, message_stream_size, msg);
       stream_set_flags (stream, MU_STREAM_RDWR);
       msg->stream = stream;
@@ -452,7 +464,7 @@ int
 message_size (message_t msg, size_t *psize)
 {
   size_t hsize, bsize;
-	int ret = 0;
+  int ret = 0;
 
   if (msg == NULL)
     return EINVAL;
@@ -461,9 +473,14 @@ message_size (message_t msg, size_t *psize)
     return msg->_size (msg, psize);
   if (psize)
     {
+      header_t hdr = NULL;
+      body_t body = NULL;
+      
       hsize = bsize = 0;
-      if ( ( ret = header_size (msg->header, &hsize) ) == 0 )
-		ret = body_size (msg->body, &bsize);
+      message_get_header (msg, &hdr);
+      message_get_body (msg, &body);
+      if ( ( ret = header_size (hdr, &hsize) ) == 0 )
+	ret = body_size (body, &bsize);
       *psize = hsize + bsize;
     }
   return ret;
@@ -472,8 +489,10 @@ message_size (message_t msg, size_t *psize)
 int
 message_get_envelope (message_t msg, envelope_t *penvelope)
 {
-  if (msg == NULL || penvelope == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (penvelope == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   if (msg->envelope == NULL)
     {
@@ -506,9 +525,10 @@ message_set_envelope (message_t msg, envelope_t envelope, void *owner)
 int
 message_get_attribute (message_t msg, attribute_t *pattribute)
 {
-  if (msg == NULL || pattribute == NULL)
-   return EINVAL;
-
+  if (msg == NULL)
+    return EINVAL;
+  if (pattribute == NULL)
+    return MU_ERR_OUT_PTR_NULL;
   if (msg->attribute == NULL)
     {
       attribute_t attribute;
@@ -606,7 +626,7 @@ message_get_uidl (message_t msg, char *buffer, size_t buflen, size_t *pwriten)
       while (stream_read (stream, buf, sizeof (buf), offset, &n) == 0
 	     && n > 0)
 	{
-	  MD5Update (&md5context, buf, n);
+	  MD5Update (&md5context, (unsigned char*)buf, n);
 	  offset += n;
 	}
       MD5Final (md5digest, &md5context);
@@ -874,9 +894,8 @@ message_write (stream_t os, const char *buf, size_t buflen,
   return status;
 }
 
-/* Implements the stream_get_fd () on the message stream.  */
 static int
-message_get_fd (stream_t stream, int *pfd)
+message_get_transport2 (stream_t stream, mu_transport_t *pin, mu_transport_t *pout)
 {
   message_t msg = stream_get_owner (stream);
   body_t body;
@@ -884,6 +903,8 @@ message_get_fd (stream_t stream, int *pfd)
 
   if (msg == NULL)
     return EINVAL;
+  if (pout)
+    *pout = NULL;
 
   /* Probably being lazy, then create a body for the stream.  */
   if (msg->body == NULL)
@@ -897,7 +918,7 @@ message_get_fd (stream_t stream, int *pfd)
       body = msg->body;
 
   body_get_stream (body, &is);
-  return stream_get_fd (is, pfd);
+  return stream_get_transport2 (is, pin, pout);
 }
 
 /* Implements the stream_stream_size () on the message stream.  */
@@ -1064,8 +1085,8 @@ message_save_to_mailbox (message_t msg, ticket_t ticket, mu_debug_t debug,
   if ((rc = mailbox_create_default (&to, toname)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      "mailbox_create_default (%s) failed: %s\n", toname,
-		      mu_errstring (rc));
+		      _("mailbox_create_default (%s) failed: %s\n"), toname,
+		      mu_strerror (rc));
       goto end;
     }
 
@@ -1095,16 +1116,16 @@ message_save_to_mailbox (message_t msg, ticket_t ticket, mu_debug_t debug,
   if ((rc = mailbox_open (to, MU_STREAM_WRITE | MU_STREAM_CREAT)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      "mailbox_open (%s) failed: %s\n", toname,
-		      mu_errstring (rc));
+		      _("mailbox_open (%s) failed: %s\n"), toname,
+		      mu_strerror (rc));
       goto end;
     }
 
   if ((rc = mailbox_append_message (to, msg)))
     {
       mu_debug_print (debug, MU_DEBUG_TRACE,
-		      "mailbox_append_message (%s) failed: %s\n", toname,
-		      mu_errstring (rc));
+		      _("mailbox_append_message (%s) failed: %s\n"), toname,
+		      mu_strerror (rc));
       goto end;
     }
 
@@ -1115,8 +1136,8 @@ end:
       if ((rc = mailbox_close (to)))
 	{
 	  mu_debug_print (debug, MU_DEBUG_TRACE,
-			  "mailbox_close (%s) failed: %s\n", toname,
-			  mu_errstring (rc));
+			  _("mailbox_close (%s) failed: %s\n"), toname,
+			  mu_strerror (rc));
 	}
     }
   else
