@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003, 2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -34,6 +34,7 @@
 #include <mailutils/stream.h>
 #include <mailutils/body.h>
 #include <mailutils/header.h>
+#include <mailutils/errno.h>
 #include <mime0.h>
 
 #ifndef TRUE
@@ -183,7 +184,7 @@ _mime_munge_content_header (char *field_body)
 	{
 	  if (*e == '\\')
 	    {			/* escaped */
-	      memmove (e, e + 1, strlen (e) + 2);
+	      memmove (e, e + 1, strlen (e));
 	    }
 	  else if (*e == '\"')
 	    quoted = ~quoted;
@@ -407,7 +408,7 @@ _mimepart_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
   int ret = 0;
 
   if (nbytes == NULL)
-    return (EINVAL);
+    return MU_ERR_OUT_NULL;
 
   *nbytes = 0;
   read_len = (int) mime_part->len - (int) off;
@@ -432,17 +433,12 @@ _mimepart_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
 }
 
 static int
-_mimepart_body_fd (stream_t stream, int *fd, int *fd2)
+_mimepart_body_transport (stream_t stream, mu_transport_t *tr1, mu_transport_t *tr2)
 {
-  if (fd2)
-    return ENOSYS;
-  else
-    {
-      body_t body = stream_get_owner (stream);
-      message_t msg = body_get_owner (body);
-      struct _mime_part *mime_part = message_get_owner (msg);
-      return stream_get_fd (mime_part->mime->stream, fd);
-    }
+  body_t body = stream_get_owner (stream);
+  message_t msg = body_get_owner (body);
+  struct _mime_part *mime_part = message_get_owner (msg);
+  return stream_get_transport2 (mime_part->mime->stream, tr1, tr2);
 }
 
 static int
@@ -661,22 +657,17 @@ _mime_body_read (stream_t stream, char *buf, size_t buflen, off_t off,
 }
 
 static int
-_mime_body_fd (stream_t stream, int *fd, int *fd2)
+_mime_body_transport (stream_t stream, mu_transport_t *tr1, mu_transport_t *tr2)
 {
-  if (fd2)
-    return ENOSYS;
-  else
-    {
-      body_t body = stream_get_owner (stream);
-      message_t msg = body_get_owner (body);
-      mime_t mime = message_get_owner (msg);
-      stream_t msg_stream = NULL;
+  body_t body = stream_get_owner (stream);
+  message_t msg = body_get_owner (body);
+  mime_t mime = message_get_owner (msg);
+  stream_t msg_stream = NULL;
 
-      if (mime->nmtp_parts == 0 || mime->cur_offset == 0)
-	return EINVAL;
-      message_get_stream (mime->mtp_parts[mime->cur_part]->msg, &msg_stream);
-      return stream_get_fd (msg_stream, fd);
-    }
+  if (mime->nmtp_parts == 0 || mime->cur_offset == 0)
+    return EINVAL;
+  message_get_stream (mime->mtp_parts[mime->cur_part]->msg, &msg_stream);
+  return stream_get_transport2 (msg_stream, tr1, tr2);
 }
 
 static int
@@ -761,7 +752,7 @@ mime_create (mime_t * pmime, message_t msg, int flags)
 	    }
 	  else
 	    {
-	      if (ret == ENOENT)
+	      if (ret == MU_ERR_NOENT)
 		{
 		  ret = 0;
 		  if ((mime->content_type =
@@ -869,7 +860,7 @@ mime_get_part (mime_t mime, size_t part, message_t * msg)
 				  body)) == 0)
 		{
 		  stream_set_read (stream, _mimepart_body_read, body);
-		  stream_set_fd (stream, _mimepart_body_fd, body);
+		  stream_set_get_transport2 (stream, _mimepart_body_transport, body);
 		  body_set_stream (body, stream, mime_part->msg);
 		  message_set_body (mime_part->msg, body, mime_part);
 		  mime_part->body_created = 1;
@@ -944,7 +935,7 @@ mime_get_message (mime_t mime, message_t * msg)
 			  == 0)
 			{
 			  stream_set_read (body_stream, _mime_body_read, body);
-			  stream_set_fd (body_stream, _mime_body_fd, body);
+			  stream_set_get_transport2 (body_stream, _mime_body_transport, body);
 			  body_set_stream (body, body_stream, mime->msg);
 			  *msg = mime->msg;
 			  return 0;
