@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -44,10 +44,14 @@
 #include <mailutils/nls.h>
 #include <mailutils/argcv.h>
 
-#define ARG_LOG_FACILITY 1
-#define ARG_LOCK_FLAGS 2
-#define ARG_SHOW_OPTIONS 3
-#define ARG_LICENSE 4
+#define ARG_LOG_FACILITY          1
+#define ARG_LOCK_FLAGS            2
+#define ARG_LOCK_RETRY_COUNT      3
+#define ARG_LOCK_RETRY_TIMEOUT    4
+#define ARG_LOCK_EXPIRE_TIMEOUT   5
+#define ARG_LOCK_EXTERNAL_PROGRAM 6
+#define ARG_SHOW_OPTIONS          7
+#define ARG_LICENSE               8
 
 static struct argp_option mu_common_argp_options[] = 
 {
@@ -69,6 +73,14 @@ static struct argp_option mu_mailbox_argp_option[] = {
    N_("Use specified URL as a mailspool directory"), 0},
   {"lock-flags", ARG_LOCK_FLAGS, N_("FLAGS"), 0,
    N_("Default locker flags (E=external, R=retry, T=time, P=pid)"), 0},
+  {"lock-retry-timeout", ARG_LOCK_RETRY_TIMEOUT, N_("SECONDS"), 0,
+   N_("Set timeout for acquiring the lockfile") },
+  {"lock-retry-count", ARG_LOCK_RETRY_COUNT, N_("NUMBER"), 0,
+   N_("Set the maximum number of times to retry acquiring the lockfile") },
+  {"lock-expire-timeout", ARG_LOCK_EXPIRE_TIMEOUT, N_("SECONDS"), 0,
+   N_("Number of seconds after which the lock expires"), },
+  {"external-locker", ARG_LOCK_EXTERNAL_PROGRAM, N_("PATH"), 0,
+   N_("Set full path to the external locker program.") },
   { NULL,      0, NULL, 0, NULL, 0 }
 };
 
@@ -108,8 +120,10 @@ static struct argp_option mu_daemon_argp_option[] = {
    N_("Set idle timeout value to NUMBER seconds"), 0},
   {"transcript", 'x', NULL, 0,
    N_("output session transcript via syslog"), 0},
+  {"pidfile", 'P', N_("FILE"), 0,
+   N_("Set PID file"), 0},
   { NULL,      0, NULL, 0, NULL, 0 }
-};  
+};
 
 static error_t mu_common_argp_parser __P((int key, char *arg,
 					  struct argp_state *state));
@@ -306,12 +320,18 @@ static char *mu_conf_option[] = {
 #ifdef ENABLE_MH
   "ENABLE_MH",
 #endif
+#ifdef ENABLE_MAILDIR
+  "ENABLE_MAILDIR",
+#endif
 #ifdef ENABLE_SMTP
   "ENABLE_SMTP",
 #endif
 #ifdef ENABLE_SENDMAIL
   "ENABLE_SENDMAIL",
 #endif
+#ifdef ENABLE_NNTP
+  "ENABLE_NNTP",
+#endif
 #ifdef WITH_INCLUDED_LIBINTL
   "WITH_INCLUDED_LIBINTL",
 #endif
@@ -400,10 +420,39 @@ mu_common_argp_parser (int key, char *arg, struct argp_state *state)
 		argp_error (state, _("invalid lock flag '%c'"), *arg);
 	      }
 	  }
-	locker_set_default_flags(flags);
+	locker_set_default_flags (flags, mu_locker_set_flags);
       }
       break;
 
+    case ARG_LOCK_RETRY_COUNT:
+      {
+	size_t t = strtoul (arg, NULL, 0);
+	locker_set_default_retry_count (t);
+	locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
+      }
+      break;
+	  
+    case ARG_LOCK_RETRY_TIMEOUT:
+      {
+	time_t t = strtoul (arg, NULL, 0);
+	locker_set_default_retry_timeout (t);
+	locker_set_default_flags (MU_LOCKER_RETRY, mu_locker_set_bit);
+      }
+      break;
+
+    case ARG_LOCK_EXPIRE_TIMEOUT:
+      {
+	time_t t = strtoul (arg, NULL, 0);
+	locker_set_default_expire_timeout (t);
+	locker_set_default_flags (MU_LOCKER_EXTERNAL, mu_locker_set_bit);
+      }
+      break;
+
+    case ARG_LOCK_EXTERNAL_PROGRAM:
+      locker_set_default_external_program (arg);
+      locker_set_default_flags (MU_LOCKER_TIME, mu_locker_set_bit);
+      break;
+      
       /* address */
     case 'E':
       if ((err = mu_set_user_email(arg)) != 0)
@@ -476,7 +525,11 @@ mu_daemon_argp_parser (int key, char *arg, struct argp_state *state)
       p->mode = MODE_DAEMON;
       p->port = strtoul (arg, NULL, 10);
       break;
-      
+
+    case 'P':
+      p->pidfile = arg;
+      break;
+
     case 't':
       p->timeout = strtoul (arg, NULL, 10);
       break;
@@ -528,11 +581,8 @@ read_rc (const char *progname, const char *name, const char *capa[],
   char* rcfile = mu_tilde_expansion (name, "/", NULL);
 
   if (!rcfile)
-    {
-      fprintf (stderr, _("%s: not enough memory\n"), progname);
-      exit (1);
-    }
-
+    return;
+  
   fp = fopen (rcfile, "r");
   if (!fp)
     {
@@ -673,19 +723,15 @@ mu_create_argcv (const char *capa[],
     struct stat s;
     char* rcdirname = mu_tilde_expansion (MU_USER_CONFIG_FILE, "/", NULL);
 
-    if (!rcdirname)
-      {
-	fprintf (stderr, _("%s: not enough memory\n"), progname);
-	exit (1);
-      }
-    if(stat(rcdirname, &s) == 0 && S_ISDIR(s.st_mode))
+    if (!rcdirname
+	|| (stat(rcdirname, &s) == 0 && S_ISDIR(s.st_mode)))
       rcdir = 1;
 
     free(rcdirname);
   }
 
   /* Add per-user config file. */
-  if(!rcdir)
+  if (!rcdir)
     {
       read_rc (progname, MU_USER_CONFIG_FILE, capa, &x_argc, &x_argv);
     }
