@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003,
+   2004 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -19,6 +20,7 @@
 # include <config.h>
 #endif
 
+#include <stdio.h>
 #include <errno.h>
 #include <string.h>
 
@@ -32,6 +34,8 @@
 const char*
 mu_errname (int e)
 {
+  static char buf[128];
+  
   switch (e)
     {
 #define EN(x)  case x: return #x
@@ -85,17 +89,39 @@ mu_errname (int e)
       EN(MU_ERR_UNSAFE_PERMS);
       EN(MU_ERR_BAD_AUTH_SCHEME);
       EN(MU_ERR_AUTH_FAILURE);
+
+      EN(MU_ERR_PROCESS_NOEXEC);
+      EN(MU_ERR_PROCESS_EXITED);
+      EN(MU_ERR_PROCESS_SIGNALED);
+      EN(MU_ERR_PROCESS_UNKNOWN_FAILURE);
+
+      EN(MU_ERR_CONN_CLOSED);
+      EN(MU_ERR_PARSE);
+      EN(MU_ERR_NOENT);
+      EN(MU_ERR_BUFSPACE);
+
+      EN(MU_ERR_SQL);
+      EN(MU_ERR_DB_ALREADY_CONNECTED);
+      EN(MU_ERR_DB_NOT_CONNECTED);
+      EN(MU_ERR_RESULT_NOT_RELEASED);
+      EN(MU_ERR_NO_QUERY);
+      EN(MU_ERR_BAD_COLUMN);
+      EN(MU_ERR_NO_RESULT);
+      EN(MU_ERR_NO_INTERFACE);
     }
 
-  return "SYSTEM ERROR";
+  snprintf (buf, sizeof buf, _("Error %d"), e);
+  return buf;
 }
 
 const char *
 mu_strerror (int e)
 {
+  const char *msg = NULL;
+  
   switch (e)
     {
-#define ES(x, d)  case x: return d
+#define ES(x, d)  case x: msg = d; break;
       ES(EOK,                     _("Success"));
       
       ES(MU_ERR_FAILURE,          _("Operation failed"));
@@ -140,8 +166,28 @@ mu_strerror (int e)
       ES(MU_ERR_UNSAFE_PERMS,     _("Unsafe file permissions. Set 0600."));
       ES(MU_ERR_BAD_AUTH_SCHEME,  _("Unsupported authentication scheme"));
       ES(MU_ERR_AUTH_FAILURE,     _("Authentication failed"));
+
+      ES(MU_ERR_PROCESS_NOEXEC,   _("Cannot execute"));
+      ES(MU_ERR_PROCESS_EXITED,   _("Process exited with a non-zero status"));
+      ES(MU_ERR_PROCESS_SIGNALED, _("Process exited on signal"));
+      ES(MU_ERR_PROCESS_UNKNOWN_FAILURE,
+	 _("Unknown failure while executing subprocess"));
+      ES(MU_ERR_CONN_CLOSED,      _("Connection closed by remote host"));
+      ES(MU_ERR_PARSE,            _("Parse error"));
+      ES(MU_ERR_NOENT,            _("Requested item not found"));
+      ES(MU_ERR_BUFSPACE,         _("Not enough buffer space"));
+
+      ES(MU_ERR_SQL,              _("SQL error"));
+      ES(MU_ERR_DB_ALREADY_CONNECTED, _("Already connected to the database"));
+      ES(MU_ERR_DB_NOT_CONNECTED,     _("Not connected to the database"));
+      ES(MU_ERR_RESULT_NOT_RELEASED,  _("Result of the previous query is not released"));
+      ES(MU_ERR_NO_QUERY,         _("No query was executed"));
+      ES(MU_ERR_BAD_COLUMN,       _("Bad column address"));
+      ES(MU_ERR_NO_RESULT,        _("No result from the previous query available"));
+
+      ES(MU_ERR_NO_INTERFACE,     _("No such interface"));
     }
 
-  return strerror (e);
+  return msg ? msg : strerror (e);
 }
 
