@@ -1,5 +1,5 @@
 
-/*  A Bison parser, made from /home/gray/new-gnu/mailutils/mh/pick.y
+/*  A Bison parser, made from /home/gray/gnu/mailutils/mh/pick.y
     by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -19,7 +19,7 @@
 #line 1 "pick.y"
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -1181,7 +1181,7 @@ pick_parse (list_t toklist)
       return 0;
     }
 
-  if (iterator_create (&iterator, toklist))
+  if (list_get_iterator (toklist, &iterator))
     return -1;
   iterator_first (iterator);
   rc = pick_yyparse ();
