@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifndef _POP3D_H
 #define _POP3D_H	1
@@ -22,6 +22,7 @@
 # include <config.h>
 #endif
 #include <mu_dbm.h>
+#include <mu_asprintf.h>
 
 /* The implementation */
 #define	IMPL		"GNU POP3 Daemon"
@@ -58,16 +59,43 @@
 /* An error occured when expunging.  */
 #define FILE_EXP        "Some deleted messages not removed"
 
+/* Command not permitted when TLS active. */
+#define TLS_ACTIVE      "Command not permitted when TLS active"
+
+/* Trying to log in within the minimum login delay interval */
+#define LOGIN_DELAY     "Attempt to log in within the minimum login delay interval"
+
 /* APOP password file, without .db or .passwd, which are added based on file
    type automatically */
 #define APOP_PASSFILE_NAME "apop"
 
 #ifdef USE_DBM
 # define APOP_PASSFILE SYSCONFDIR "/" APOP_PASSFILE_NAME
+# define ENABLE_LOGIN_DELAY
 #else
 # define APOP_PASSFILE SYSCONFDIR "/" APOP_PASSFILE_NAME ".passwd"
+# undef ENABLE_LOGIN_DELAY
 #endif
 
+#ifdef ENABLE_LOGIN_DELAY
+# define LOGIN_STAT_FILE "/var/run/pop3-login"
+extern time_t login_delay;
+extern char *login_stat_file;
+extern int check_login_delay __P((char *username));
+extern void update_login_delay __P((char *username));
+extern void login_delay_capa __P((void));
+#else
+# define check_login_delay(u) 0
+# define update_login_delay(u)
+# define login_delay_capa()
+#endif
+
+/* Minimum advertise retention time for messages.  */
+extern time_t expire;
+extern int expire_on_exit;
+
+#define EXPIRE_NEVER ((time_t)-1)
+
 /* Size of the MD5 digest for APOP */
 #define APOP_DIGEST	70
 
@@ -111,6 +139,7 @@
 #include <mailutils/argp.h>
 #include <mailutils/attribute.h>
 #include <mailutils/body.h>
+#include <mailutils/daemon.h>
 #include <mailutils/errno.h>
 #include <mailutils/error.h>
 #include <mailutils/header.h>
@@ -119,9 +148,11 @@
 #include <mailutils/mailbox.h>
 #include <mailutils/message.h>
 #include <mailutils/mutil.h>
-#include <mailutils/registrar.h>
-#include <mailutils/url.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/nls.h>
+#include <mailutils/registrar.h>
+#include <mailutils/tls.h>
+#include <mailutils/url.h>
 
 /* For Berkley DB2 APOP password file */
 #ifdef HAVE_DB_H
@@ -138,11 +169,14 @@
 
 #ifndef MAXHOSTNAMELEN
 /* Maximum length of a hostname (is this defined somewhere else?).  */
-/* MAXHOSTNAMELEN is already define on Solaris.  */
-#define MAXHOSTNAMELEN	64
+/* MAXHOSTNAMELEN is already defined on Solaris.  */
+# define MAXHOSTNAMELEN	64
 #endif
 
+#define POP3_ATTRIBUTE_DELE 0x0001
+#define POP3_ATTRIBUTE_RETR 0x0010
 
+#define INITIAL        -1
 #define AUTHORIZATION	0
 #define TRANSACTION	1
 #define UPDATE		2
@@ -164,18 +198,26 @@
 #define ERR_TIMEOUT	14
 #define ERR_UNKNOWN	15
 #define ERR_MBOX_SYNC   16
+#define ERR_TLS_ACTIVE  17
+#define ERR_TLS_IO      18
+#define ERR_LOGIN_DELAY 19
 
 extern mailbox_t mbox;
 extern int state;
+extern int initial_state;
 extern char *username;
 extern char *maildir;
-extern FILE *ifile;
-extern FILE *ofile;
 extern char *md5shared;
-extern volatile size_t children;
+extern size_t children;
 extern struct daemon_param daemon_param;
 extern int debug_mode;
+#ifdef WITH_TLS
+extern int tls_available;
+extern int tls_done;
+#endif /* WITH_TLS */
+extern int undelete_on_startup;
 
+extern void pop3d_bye           __P ((void));
 extern int pop3d_abquit         __P ((int));
 extern int pop3d_apop           __P ((const char *));
 extern char *pop3d_apopuser     __P ((const char *));
@@ -188,12 +230,16 @@ extern int pop3d_list           __P ((const char *));
 extern int pop3d_lock           __P ((void));
 extern int pop3d_noop           __P ((const char *));
 extern int pop3d_quit           __P ((const char *));
-extern char *pop3d_readline     __P ((FILE *));
 extern int pop3d_retr           __P ((const char *));
 extern int pop3d_rset           __P ((const char *));
+extern void process_cleanup     __P ((void));
+
 extern RETSIGTYPE pop3d_sigchld __P ((int));
 extern RETSIGTYPE pop3d_signal  __P ((int));
 extern int pop3d_stat           __P ((const char *));
+#ifdef WITH_TLS
+extern int pop3d_stls           __P ((const char *));
+#endif /* WITH_TLS */
 extern int pop3d_top            __P ((const char *));
 extern int pop3d_touchlock      __P ((void));
 extern int pop3d_uidl           __P ((const char *));
@@ -201,6 +247,27 @@ extern int pop3d_user           __P ((const char *));
 extern int pop3d_unlock         __P ((void));
 extern void pop3d_outf          __P ((const char *fmt, ...));
 
-extern struct passwd * getpwnam_ip_virtual   __P ((const char *u));
-extern struct passwd * getpwnam_host_virtual __P ((const char *u));
+extern void pop3d_setio         __P ((FILE *in, FILE *out));
+extern char *pop3d_readline     __P ((char *, size_t));
+extern void pop3d_flush_output  __P ((void));
+
+extern int pop3d_is_master      __P ((void));
+
+extern void pop3d_mark_deleted __P((attribute_t attr));
+extern int pop3d_is_deleted __P((attribute_t attr));
+extern void pop3d_unset_deleted __P((attribute_t attr));
+void pop3d_undelete_all __P((void));
+
+#ifdef WITH_TLS
+extern int pop3d_init_tls_server    __P ((void));
+extern void pop3d_deinit_tls_server __P ((void));
+#endif /* WITH_TLS */
+
+extern void pop3d_mark_retr __P((attribute_t attr));
+extern int pop3d_is_retr __P((attribute_t attr));
+extern void pop3d_unmark_retr __P((attribute_t attr));
+
+extern void expire_mark_message __P((message_t msg, char **value));
+
+
 #endif /* _POP3D_H */
